#pragma once

#include "B5Plugin.h"
#include "PluginRevisions.h"

#include "PluginOptionList.h"
#include "PluginImageSettings.h"

#include <QString>
#include <QObject>
#include <QCheckBox>

#define PLUGINNAME	"Mix3"				// The  plugin group/owner name for all of your plug-in's settings keep it short but unique
#define PLUGINGROUP	"Mix3"

//	Define here the names and IDs of your controls. 
//	Note that the buttons don't need IDs

#define FP_MIX3_ENABLED			"mix3_enabled"			// Boolean - is the plug-in enabled?
#define FP_MIX3_EARLY			"mix3_early"			// Boolean - is the plug-in to be run early?
#define	FP_MIX3_RESET			"mix3_reset"			// Reset Button
#define FP_MIX3_ABOUT			"mix3_about"			// About button
#define FP_MIX3_EXPOSURE		"mix3_exposure"			// Exposure slider
#define FP_MIX3_RED		        "mix3_red"	            // Red slider
#define FP_MIX3_GREEN			"mix3_green"			// Green definition slider
#define FP_MIX3_BLUE			"mix3_blue"				// Blue level slider

#define ID_MIX3_ENABLED			100
#define ID_MIX3_EARLY			101
#define	ID_MIX3_RESETOPT		102
#define ID_MIX3_EXPOSURE		103
#define ID_MIX3_RED		        104
#define ID_MIX3_GREEN			105
#define ID_MIX3_BLUE			106

//	The Plugin class
class Mix3Plugin : public QObject, public B5Plugin
{
        Q_OBJECT

public:
	Mix3Plugin() : m_hub( NULL ), m_id( -1 ), m_groupId( -1 ), m_pWindow( NULL ) { ; }
	virtual int priority() { return 800; }
	virtual QString name() { return QString(PLUGINNAME); }
	virtual QString group() { return QString(PLUGINGROUP); }
	virtual bool init(PluginHub *hub, int id, int groupId, const QString &bundlePath);
	virtual bool registerFilters();
	virtual bool registerOptions();
	virtual bool finish();
	virtual PluginDependency *createDependency(const QString &name);
	virtual QList<QString> toolFiles();
	virtual QList<QWidget*> toolWidgets();
	virtual void toolWidgetCreated(QWidget *uiWidget);

private slots:
	void showAbout() const;
	void resetControls() const;
	void handleSettingsChange(const PluginImageSettings &options, const PluginImageSettings &changed, int currentLayer);
	void handleControlChange(const QString &optionName, int groupId, int layer, const PluginImageSettings &options, const PluginOptionList &current, PluginOptionList &changes);
	void handleHotnessChanged(const PluginImageSettings &options);

private:
	PluginHub *m_hub;
	int m_id;
	int m_groupId;
	QWidget *m_pWindow;
};
